@@ -53,6 +53,11 @@ class QueryConstraint(BaseModel):
     class Config:
         extra = 'forbid'
 
+    def dict(self, *args, **kwargs):
+        output = super().dict(*args, **kwargs)
+        output['not'] = output.pop('negated', False)
+        return output
+
 
 class QNode(BaseModel):
     """Query node."""
